==> haskell-math-functions-0.2.1.0-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-math-functions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: math-functions
version: 0.2.1.0
id: math-functions-0.2.1.0-5nxcwN7qdrw9KmeUhayRSI
key: math-functions-0.2.1.0-5nxcwN7qdrw9KmeUhayRSI
license: BSD3
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/math-functions
synopsis: Special functions and Chebyshev polynomials
description:
    This library provides implementations of special mathematical
    functions and Chebyshev polynomials.  These functions are often
    useful in statistical and numerical computing.
category: Math, Numeric
author: Bryan O'\''Sullivan <bos@serpentine.com>,
        Aleksey Khudyakov <alexey.skladnoy@gmail.com>
exposed: True
exposed-modules:
    Numeric.MathFunctions.Constants Numeric.MathFunctions.Comparison
    Numeric.Polynomial Numeric.Polynomial.Chebyshev Numeric.RootFinding
    Numeric.SpecFunctions Numeric.SpecFunctions.Extra Numeric.Series
    Numeric.Sum
hidden-modules: Numeric.SpecFunctions.Internal
abi: 316015a4ace700383a9c04c77e845b0e
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/math-functions-0.2.1.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/math-functions-0.2.1.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/math-functions-0.2.1.0
hs-libraries: HSmath-functions-0.2.1.0-5nxcwN7qdrw9KmeUhayRSI
depends:
    base-4.9.0.0 deepseq-1.4.2.0
    primitive-0.6.1.0-Ip44DqhfCp21tTUYbecwa
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
    vector-th-unbox-0.2.1.6-GMTpzttBvqGAEXamQ10jEK
haddock-interfaces: /usr/share/doc/haskell-math-functions/html/math-functions.haddock
haddock-html: /usr/share/doc/haskell-math-functions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-math-functions-0.2.1.0-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-math-functions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: math-functions
version: 0.2.1.0
id: math-functions-0.2.1.0-31FvveTLTlqClGw5YZ5Avx
key: math-functions-0.2.1.0-31FvveTLTlqClGw5YZ5Avx
license: BSD3
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/math-functions
synopsis: Special functions and Chebyshev polynomials
description:
    This library provides implementations of special mathematical
    functions and Chebyshev polynomials.  These functions are often
    useful in statistical and numerical computing.
category: Math, Numeric
author: Bryan O'\''Sullivan <bos@serpentine.com>,
        Aleksey Khudyakov <alexey.skladnoy@gmail.com>
exposed: True
exposed-modules:
    Numeric.MathFunctions.Constants Numeric.MathFunctions.Comparison
    Numeric.Polynomial Numeric.Polynomial.Chebyshev Numeric.RootFinding
    Numeric.SpecFunctions Numeric.SpecFunctions.Extra Numeric.Series
    Numeric.Sum
hidden-modules: Numeric.SpecFunctions.Internal
abi: 69c1f607b0d4bc2c3a9b8196db851a84
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/math-functions-0.2.1.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/math-functions-0.2.1.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/math-functions-0.2.1.0
hs-libraries: HSmath-functions-0.2.1.0-31FvveTLTlqClGw5YZ5Avx
depends:
    base-4.9.0.0 deepseq-1.4.2.0
    primitive-0.6.2.0-3HSsNCfUEEE4fjqDYVydYZ
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
    vector-th-unbox-0.2.1.6-KTWDDIPkmKEAVfyzm77bHY
haddock-interfaces: /usr/share/doc/haskell-math-functions/html/math-functions.haddock
haddock-html: /usr/share/doc/haskell-math-functions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
